@@ -1,19 +1,24 @@
 import logging, sys
 
 
-def setup_logger(log_level):
+def sane_logger(log_level=logging.INFO):
   logger = logging.getLogger()
+
+  if hasattr(logger, 'sane_logger_called'):
+    return logger
+  logger.sane_logger_called = True
+
   logger.setLevel(log_level)
 
   sh = logging.StreamHandler(sys.stdout)
   formatter = logging.Formatter(
     '[%(asctime)s] %(levelname)s [%(filename)s.%(funcName)s:%(lineno)d] %(message)s',
-    datefmt='%a, %d %b %Y %H:%M:%S'
+    datefmt='%a, %d %b %Y %H:%M:%S %Z'
   )
   sh.setFormatter(formatter)
   logger.addHandler(sh)
   return logger
 
 if __name__ == '__main__':
-  logger = setup_logger(logging.DEBUG)
+  logger = sane_logger(logging.DEBUG)
   logger.info('test log')
